==> eam-wshub-proxyclient-11.4-8-sources.jar: net/datastream/schemas/mp_entities/picklist_001/PickList.java <==

package net.datastream.schemas.mp_entities.picklist_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.DELIVERYADDRESS_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PICKLIST_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.SUPPLIERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERID_Type;
import net.datastream.schemas.mp_fields.WORKORDERACTIVITY;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PICKLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYADDRESSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYSUPPLIERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERPERSONNEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORIGINID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULTAPPROVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "picklistid",
    "storeid",
    "status",
    "daterequired",
    "classid",
    "workorderactivity",
    "jobsequence",
    "assetid",
    "deliveryaddressid",
    "deliverysupplierid",
    "deliverpersonnel",
    "originid",
    "defaultapprover",
    "approver",
    "approvedate",
    "userdefinedarea"
})
@XmlRootElement(name = "PickList")
public class PickList {

    @XmlElement(name = "PICKLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PICKLIST_Type picklistid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "DATEREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequired;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "WORKORDERACTIVITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected WORKORDERACTIVITY workorderactivity;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "DELIVERYADDRESSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DELIVERYADDRESS_Type deliveryaddressid;
    @XmlElement(name = "DELIVERYSUPPLIERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SUPPLIERID_Type deliverysupplierid;
    @XmlElement(name = "DELIVERPERSONNEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type deliverpersonnel;
    @XmlElement(name = "ORIGINID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type originid;
    @XmlElement(name = "DEFAULTAPPROVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type defaultapprover;
    @XmlElement(name = "APPROVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approver;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété picklistid.
     * 
     * @return
     *     possible object is
     *     {@link PICKLIST_Type }
     *     
     */
    public PICKLIST_Type getPICKLISTID() {
        return picklistid;
    }

    /**
     * Définit la valeur de la propriété picklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link PICKLIST_Type }
     *     
     */
    public void setPICKLISTID(PICKLIST_Type value) {
        this.picklistid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété daterequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUIRED() {
        return daterequired;
    }

    /**
     * Définit la valeur de la propriété daterequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUIRED(DATETIME value) {
        this.daterequired = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderactivity.
     * 
     * @return
     *     possible object is
     *     {@link WORKORDERACTIVITY }
     *     
     */
    public WORKORDERACTIVITY getWORKORDERACTIVITY() {
        return workorderactivity;
    }

    /**
     * Définit la valeur de la propriété workorderactivity.
     * 
     * @param value
     *     allowed object is
     *     {@link WORKORDERACTIVITY }
     *     
     */
    public void setWORKORDERACTIVITY(WORKORDERACTIVITY value) {
        this.workorderactivity = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété deliveryaddressid.
     * 
     * @return
     *     possible object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public DELIVERYADDRESS_Type getDELIVERYADDRESSID() {
        return deliveryaddressid;
    }

    /**
     * Définit la valeur de la propriété deliveryaddressid.
     * 
     * @param value
     *     allowed object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public void setDELIVERYADDRESSID(DELIVERYADDRESS_Type value) {
        this.deliveryaddressid = value;
    }

    /**
     * Obtient la valeur de la propriété deliverysupplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getDELIVERYSUPPLIERID() {
        return deliverysupplierid;
    }

    /**
     * Définit la valeur de la propriété deliverysupplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setDELIVERYSUPPLIERID(SUPPLIERID_Type value) {
        this.deliverysupplierid = value;
    }

    /**
     * Obtient la valeur de la propriété deliverpersonnel.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getDELIVERPERSONNEL() {
        return deliverpersonnel;
    }

    /**
     * Définit la valeur de la propriété deliverpersonnel.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setDELIVERPERSONNEL(PERSONID_Type value) {
        this.deliverpersonnel = value;
    }

    /**
     * Obtient la valeur de la propriété originid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getORIGINID() {
        return originid;
    }

    /**
     * Définit la valeur de la propriété originid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setORIGINID(USERID_Type value) {
        this.originid = value;
    }

    /**
     * Obtient la valeur de la propriété defaultapprover.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getDEFAULTAPPROVER() {
        return defaultapprover;
    }

    /**
     * Définit la valeur de la propriété defaultapprover.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setDEFAULTAPPROVER(USERID_Type value) {
        this.defaultapprover = value;
    }

    /**
     * Obtient la valeur de la propriété approver.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVER() {
        return approver;
    }

    /**
     * Définit la valeur de la propriété approver.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVER(USERID_Type value) {
        this.approver = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}

==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/picklist_001/PickList.java <==

package net.datastream.schemas.mp_entities.picklist_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CLASSID_Type;
import net.datastream.schemas.mp_fields.DELIVERYADDRESS_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.PERSONID_Type;
import net.datastream.schemas.mp_fields.PICKLIST_Type;
import net.datastream.schemas.mp_fields.STATUS_Type;
import net.datastream.schemas.mp_fields.STOREID_Type;
import net.datastream.schemas.mp_fields.SUPPLIERID_Type;
import net.datastream.schemas.mp_fields.USERDEFINEDAREA;
import net.datastream.schemas.mp_fields.USERID_Type;
import net.datastream.schemas.mp_fields.WORKORDERACTIVITY;
import org.openapplications.oagis_segments.DATETIME;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PICKLISTID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STOREID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}STATUS" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATEREQUIRED" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CLASSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}WORKORDERACTIVITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}JOBSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYADDRESSID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERYSUPPLIERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DELIVERPERSONNEL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ORIGINID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULTAPPROVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}APPROVEDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRINTDATE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERDEFINEDAREA" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="recordid" type="{http://www.w3.org/2001/XMLSchema}long" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "picklistid",
    "storeid",
    "status",
    "daterequired",
    "classid",
    "workorderactivity",
    "jobsequence",
    "assetid",
    "deliveryaddressid",
    "deliverysupplierid",
    "deliverpersonnel",
    "originid",
    "defaultapprover",
    "approver",
    "approvedate",
    "printdate",
    "userdefinedarea"
})
@XmlRootElement(name = "PickList")
public class PickList {

    @XmlElement(name = "PICKLISTID", namespace = "http://schemas.datastream.net/MP_fields")
    protected PICKLIST_Type picklistid;
    @XmlElement(name = "STOREID", namespace = "http://schemas.datastream.net/MP_fields")
    protected STOREID_Type storeid;
    @XmlElement(name = "STATUS", namespace = "http://schemas.datastream.net/MP_fields")
    protected STATUS_Type status;
    @XmlElement(name = "DATEREQUIRED", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME daterequired;
    @XmlElement(name = "CLASSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CLASSID_Type classid;
    @XmlElement(name = "WORKORDERACTIVITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected WORKORDERACTIVITY workorderactivity;
    @XmlElement(name = "JOBSEQUENCE", namespace = "http://schemas.datastream.net/MP_fields")
    protected Long jobsequence;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "DELIVERYADDRESSID", namespace = "http://schemas.datastream.net/MP_fields")
    protected DELIVERYADDRESS_Type deliveryaddressid;
    @XmlElement(name = "DELIVERYSUPPLIERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected SUPPLIERID_Type deliverysupplierid;
    @XmlElement(name = "DELIVERPERSONNEL", namespace = "http://schemas.datastream.net/MP_fields")
    protected PERSONID_Type deliverpersonnel;
    @XmlElement(name = "ORIGINID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type originid;
    @XmlElement(name = "DEFAULTAPPROVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type defaultapprover;
    @XmlElement(name = "APPROVER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type approver;
    @XmlElement(name = "APPROVEDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME approvedate;
    @XmlElement(name = "PRINTDATE", namespace = "http://schemas.datastream.net/MP_fields")
    protected DATETIME printdate;
    @XmlElement(name = "USERDEFINEDAREA", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERDEFINEDAREA userdefinedarea;
    @XmlAttribute(name = "recordid")
    protected Long recordid;

    /**
     * Obtient la valeur de la propriété picklistid.
     * 
     * @return
     *     possible object is
     *     {@link PICKLIST_Type }
     *     
     */
    public PICKLIST_Type getPICKLISTID() {
        return picklistid;
    }

    /**
     * Définit la valeur de la propriété picklistid.
     * 
     * @param value
     *     allowed object is
     *     {@link PICKLIST_Type }
     *     
     */
    public void setPICKLISTID(PICKLIST_Type value) {
        this.picklistid = value;
    }

    /**
     * Obtient la valeur de la propriété storeid.
     * 
     * @return
     *     possible object is
     *     {@link STOREID_Type }
     *     
     */
    public STOREID_Type getSTOREID() {
        return storeid;
    }

    /**
     * Définit la valeur de la propriété storeid.
     * 
     * @param value
     *     allowed object is
     *     {@link STOREID_Type }
     *     
     */
    public void setSTOREID(STOREID_Type value) {
        this.storeid = value;
    }

    /**
     * Obtient la valeur de la propriété status.
     * 
     * @return
     *     possible object is
     *     {@link STATUS_Type }
     *     
     */
    public STATUS_Type getSTATUS() {
        return status;
    }

    /**
     * Définit la valeur de la propriété status.
     * 
     * @param value
     *     allowed object is
     *     {@link STATUS_Type }
     *     
     */
    public void setSTATUS(STATUS_Type value) {
        this.status = value;
    }

    /**
     * Obtient la valeur de la propriété daterequired.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getDATEREQUIRED() {
        return daterequired;
    }

    /**
     * Définit la valeur de la propriété daterequired.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setDATEREQUIRED(DATETIME value) {
        this.daterequired = value;
    }

    /**
     * Obtient la valeur de la propriété classid.
     * 
     * @return
     *     possible object is
     *     {@link CLASSID_Type }
     *     
     */
    public CLASSID_Type getCLASSID() {
        return classid;
    }

    /**
     * Définit la valeur de la propriété classid.
     * 
     * @param value
     *     allowed object is
     *     {@link CLASSID_Type }
     *     
     */
    public void setCLASSID(CLASSID_Type value) {
        this.classid = value;
    }

    /**
     * Obtient la valeur de la propriété workorderactivity.
     * 
     * @return
     *     possible object is
     *     {@link WORKORDERACTIVITY }
     *     
     */
    public WORKORDERACTIVITY getWORKORDERACTIVITY() {
        return workorderactivity;
    }

    /**
     * Définit la valeur de la propriété workorderactivity.
     * 
     * @param value
     *     allowed object is
     *     {@link WORKORDERACTIVITY }
     *     
     */
    public void setWORKORDERACTIVITY(WORKORDERACTIVITY value) {
        this.workorderactivity = value;
    }

    /**
     * Obtient la valeur de la propriété jobsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getJOBSEQUENCE() {
        return jobsequence;
    }

    /**
     * Définit la valeur de la propriété jobsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setJOBSEQUENCE(Long value) {
        this.jobsequence = value;
    }

    /**
     * Obtient la valeur de la propriété assetid.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Définit la valeur de la propriété assetid.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Obtient la valeur de la propriété deliveryaddressid.
     * 
     * @return
     *     possible object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public DELIVERYADDRESS_Type getDELIVERYADDRESSID() {
        return deliveryaddressid;
    }

    /**
     * Définit la valeur de la propriété deliveryaddressid.
     * 
     * @param value
     *     allowed object is
     *     {@link DELIVERYADDRESS_Type }
     *     
     */
    public void setDELIVERYADDRESSID(DELIVERYADDRESS_Type value) {
        this.deliveryaddressid = value;
    }

    /**
     * Obtient la valeur de la propriété deliverysupplierid.
     * 
     * @return
     *     possible object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public SUPPLIERID_Type getDELIVERYSUPPLIERID() {
        return deliverysupplierid;
    }

    /**
     * Définit la valeur de la propriété deliverysupplierid.
     * 
     * @param value
     *     allowed object is
     *     {@link SUPPLIERID_Type }
     *     
     */
    public void setDELIVERYSUPPLIERID(SUPPLIERID_Type value) {
        this.deliverysupplierid = value;
    }

    /**
     * Obtient la valeur de la propriété deliverpersonnel.
     * 
     * @return
     *     possible object is
     *     {@link PERSONID_Type }
     *     
     */
    public PERSONID_Type getDELIVERPERSONNEL() {
        return deliverpersonnel;
    }

    /**
     * Définit la valeur de la propriété deliverpersonnel.
     * 
     * @param value
     *     allowed object is
     *     {@link PERSONID_Type }
     *     
     */
    public void setDELIVERPERSONNEL(PERSONID_Type value) {
        this.deliverpersonnel = value;
    }

    /**
     * Obtient la valeur de la propriété originid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getORIGINID() {
        return originid;
    }

    /**
     * Définit la valeur de la propriété originid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setORIGINID(USERID_Type value) {
        this.originid = value;
    }

    /**
     * Obtient la valeur de la propriété defaultapprover.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getDEFAULTAPPROVER() {
        return defaultapprover;
    }

    /**
     * Définit la valeur de la propriété defaultapprover.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setDEFAULTAPPROVER(USERID_Type value) {
        this.defaultapprover = value;
    }

    /**
     * Obtient la valeur de la propriété approver.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getAPPROVER() {
        return approver;
    }

    /**
     * Définit la valeur de la propriété approver.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setAPPROVER(USERID_Type value) {
        this.approver = value;
    }

    /**
     * Obtient la valeur de la propriété approvedate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getAPPROVEDATE() {
        return approvedate;
    }

    /**
     * Définit la valeur de la propriété approvedate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setAPPROVEDATE(DATETIME value) {
        this.approvedate = value;
    }

    /**
     * Obtient la valeur de la propriété printdate.
     * 
     * @return
     *     possible object is
     *     {@link DATETIME }
     *     
     */
    public DATETIME getPRINTDATE() {
        return printdate;
    }

    /**
     * Définit la valeur de la propriété printdate.
     * 
     * @param value
     *     allowed object is
     *     {@link DATETIME }
     *     
     */
    public void setPRINTDATE(DATETIME value) {
        this.printdate = value;
    }

    /**
     * Obtient la valeur de la propriété userdefinedarea.
     * 
     * @return
     *     possible object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public USERDEFINEDAREA getUSERDEFINEDAREA() {
        return userdefinedarea;
    }

    /**
     * Définit la valeur de la propriété userdefinedarea.
     * 
     * @param value
     *     allowed object is
     *     {@link USERDEFINEDAREA }
     *     
     */
    public void setUSERDEFINEDAREA(USERDEFINEDAREA value) {
        this.userdefinedarea = value;
    }

    /**
     * Obtient la valeur de la propriété recordid.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRecordid() {
        return recordid;
    }

    /**
     * Définit la valeur de la propriété recordid.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRecordid(Long value) {
        this.recordid = value;
    }

}
